@@ -33,46 +33,53 @@
 #define _GNU_SOURCE
 #include <getopt.h>
 
-#include <lxc/lxc.h>
-#include <lxc/log.h>
-#include <lxc/utils.h>
-#include <lxc/error.h>
+#include "log.h"
+#include "caps.h"
+#include "error.h"
+#include "utils.h"
 
 lxc_log_define(lxc_init, lxc);
 
-static char const *log_file;
-static char const *log_priority;
 static int quiet;
 
 static struct option options[] = {
-	{ "logfile", required_argument, 0, 'o' },
-	{ "logpriority", required_argument, 0, 'l' },
 	{ "quiet", no_argument, &quiet, 1 },
 	{ 0, 0, 0, 0 },
 };
 
+static	int was_interrupted = 0;
+
 int main(int argc, char *argv[])
 {
+
+	void interrupt_handler(int sig)
+	{
+		if (!was_interrupted)
+			was_interrupted = sig;
+	}
+
 	pid_t pid;
 	int nbargs = 0;
 	int err = -1;
 	char **aargv;
+	sigset_t mask, omask;
+	int i, shutdown = 0;
 
 	while (1) {
 		int ret = getopt_long_only(argc, argv, "", options, NULL);
 		if (ret == -1) {
 			break;
 		}
-		switch (ret) {
-		case 'o':	log_file = optarg; break;
-		case 'l':	log_priority = optarg; break;
-		case '?':
+		if  (ret == '?')
 			exit(err);
-		}
+
 		nbargs++;
 	}
 
-	if (lxc_log_init(log_file, log_priority, basename(argv[0]), quiet))
+	if (lxc_caps_init())
+		exit(err);
+
+	if (lxc_log_init(NULL, 0, basename(argv[0]), quiet))
 		exit(err);
 
 	if (!argv[optind]) {
@@ -83,28 +90,58 @@ int main(int argc, char *argv[])
 	aargv = &argv[optind];
 	argc -= nbargs;
 
+        /*
+	 * mask all the signals so we are safe to install a
+	 * signal handler and to fork
+	 */
+	sigfillset(&mask);
+	sigprocmask(SIG_SETMASK, &mask, &omask);
+
+	for (i = 1; i < NSIG; i++) {
+		struct sigaction act;
+
+		sigfillset(&act.sa_mask);
+		sigdelset(&mask, SIGILL);
+		sigdelset(&mask, SIGSEGV);
+		sigdelset(&mask, SIGBUS);
+		act.sa_flags = 0;
+		act.sa_handler = interrupt_handler;
+		sigaction(i, &act, NULL);
+	}
+
+	if (lxc_setup_fs())
+		exit(err);
+
+	if (lxc_caps_reset())
+		exit(err);
+
 	pid = fork();
-	
+
 	if (pid < 0)
 		exit(err);
 
 	if (!pid) {
-		
-		if (lxc_setup_fs())
-			exit(err);
+
+		/* restore default signal handlers */
+		for (i = 1; i < NSIG; i++)
+			signal(i, SIG_DFL);
+
+		sigprocmask(SIG_SETMASK, &omask, NULL);
 
 		NOTICE("about to exec '%s'", aargv[0]);
 
 		execvp(aargv[0], aargv);
-		ERROR("failed to exec: '%s' : %s", aargv[0], strerror(errno));
+		ERROR("failed to exec: '%s' : %m", aargv[0]);
 		exit(err);
 	}
 
-	err = lxc_close_all_inherited_fd();
-	if (err) {
-		ERROR("unable to close inherited fds");
-		goto out;
-	}
+	/* let's process the signals now */
+	sigdelset(&omask, SIGALRM);
+	sigprocmask(SIG_SETMASK, &omask, NULL);
+
+	/* no need of other inherited fds but stderr */
+	close(fileno(stdin));
+	close(fileno(stdout));
 
 	err = 0;
 	for (;;) {
@@ -112,19 +149,49 @@ int main(int argc, char *argv[])
 		int orphan = 0;
 		pid_t waited_pid;
 
+		switch (was_interrupted) {
+
+		case 0:
+			break;
+
+		case SIGTERM:
+			if (!shutdown) {
+				shutdown = 1;
+				kill(-1, SIGTERM);
+				alarm(1);
+			}
+			break;
+
+		case SIGALRM:
+			kill(-1, SIGKILL);
+			break;
+
+		default:
+			kill(pid, was_interrupted);
+			break;
+		}
+
+		was_interrupted = 0;
 		waited_pid = wait(&status);
 		if (waited_pid < 0) {
 			if (errno == ECHILD)
 				goto out;
 			if (errno == EINTR)
 				continue;
-			ERROR("failed to wait child : %s", strerror(errno));
+
+			ERROR("failed to wait child : %s",
+			      strerror(errno));
 			goto out;
 		}
 
+		/* reset timer each time a process exited */
+		if (shutdown)
+			alarm(1);
+
 		/*
-		 * keep the exit code of started application (not wrapped pid)
-		 * and continue to wait for the end of the orphan group.
+		 * keep the exit code of started application
+		 * (not wrapped pid) and continue to wait for
+		 * the end of the orphan group.
 		 */
 		if ((waited_pid != pid) || (orphan ==1))
 			continue;
@@ -134,4 +201,3 @@ int main(int argc, char *argv[])
 out:
 	return err;
 }
-
